@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2015 various contributors (see AUTHORS)
+ * Copyright (C) 2007-2022 various contributors (see AUTHORS)
  * 
  * This file is part of Python-EFL.
  * 
@@ -35,7 +35,6 @@ struct E_DBus_Connection
   Eina_List *fd_handlers;
   Eina_List *timeouts;
   Ecore_Idler *idler;
-  int refcount;
 };
 
 struct E_DBus_Handler_Data
@@ -52,7 +51,6 @@ struct E_DBus_Timeout_Data
   Ecore_Timer *handler;
   DBusTimeout *timeout;
   E_DBus_Connection *cd;
-  int interval;
 };
 
 
